@@ -2,12 +2,10 @@
 
 namespace SimpleSAML\Auth;
 
-use \SimpleSAML_Auth_Source as Source;
-use \SimpleSAML_Auth_State as State;
-use \SimpleSAML_Configuration as Configuration;
-use \SimpleSAML_Error_AuthSource as AuthSourceError;
+use \SimpleSAML\Configuration;
+use \SimpleSAML\Error\AuthSource as AuthSourceError;
 use \SimpleSAML\Module;
-use \SimpleSAML_Session as Session;
+use \SimpleSAML\Session;
 use \SimpleSAML\Utils\HTTP;
 
 /**
@@ -15,9 +13,9 @@ use \SimpleSAML\Utils\HTTP;
  *
  * @package SimpleSAMLphp
  */
+
 class Simple
 {
-
     /**
      * The id of the authentication source we are accessing.
      *
@@ -25,31 +23,43 @@ class Simple
      */
     protected $authSource;
 
-    /**
-     * @var \SimpleSAML_Configuration|null
-     */
+    /** @var \SimpleSAML\Configuration */
     protected $app_config;
 
+    /** @var \SimpleSAML\Session */
+    protected $session;
+
+
     /**
      * Create an instance with the specified authsource.
      *
      * @param string $authSource The id of the authentication source.
+     * @param \SimpleSAML\Configuration|null $config Optional configuration to use.
+     * @param \SimpleSAML\Session|null $session Optional session to use.
      */
-    public function __construct($authSource)
+    public function __construct($authSource, Configuration $config = null, Session $session = null)
     {
         assert(is_string($authSource));
 
+        if ($config === null) {
+            $config = Configuration::getInstance();
+        }
         $this->authSource = $authSource;
-        $this->app_config = Configuration::getInstance()->getConfigItem('application', null);
+        $this->app_config = $config->getConfigItem('application', null);
+
+        if ($session === null) {
+            $session = Session::getSessionFromRequest();
+        }
+        $this->session = $session;
     }
 
 
     /**
      * Retrieve the implementing authentication source.
      *
-     * @return \SimpleSAML_Auth_Source The authentication source.
+     * @return Source The authentication source.
      *
-     * @throws \SimpleSAML_Error_AuthSource If the requested auth source is unknown.
+     * @throws AuthSourceError If the requested auth source is unknown.
      */
     public function getAuthSource()
     {
@@ -71,9 +81,7 @@ class Simple
      */
     public function isAuthenticated()
     {
-        $session = Session::getSessionFromRequest();
-
-        return $session->isValid($this->authSource);
+        return $this->session->isValid($this->authSource);
     }
 
 
@@ -90,12 +98,9 @@ class Simple
      *
      * @param array $params Various options to the authentication request. See the documentation.
      */
-    public function requireAuth(array $params = array())
+    public function requireAuth(array $params = [])
     {
-
-        $session = Session::getSessionFromRequest();
-
-        if ($session->isValid($this->authSource)) {
+        if ($this->session->isValid($this->authSource)) {
             // Already authenticated
             return;
         }
@@ -118,9 +123,8 @@ class Simple
      *
      * @param array $params Various options to the authentication request.
      */
-    public function login(array $params = array())
+    public function login(array $params = [])
     {
-
         if (array_key_exists('KeepPost', $params)) {
             $keepPost = (bool) $params['KeepPost'];
         } else {
@@ -187,9 +191,9 @@ class Simple
         }
 
         if (is_string($params)) {
-            $params = array(
+            $params = [
                 'ReturnTo' => $params,
-            );
+            ];
         }
 
         assert(is_array($params));
@@ -199,16 +203,15 @@ class Simple
             assert(isset($params['ReturnStateParam'], $params['ReturnStateStage']));
         }
 
-        $session = Session::getSessionFromRequest();
-        if ($session->isValid($this->authSource)) {
-            $state = $session->getAuthData($this->authSource, 'LogoutState');
+        if ($this->session->isValid($this->authSource)) {
+            $state = $this->session->getAuthData($this->authSource, 'LogoutState');
             if ($state !== null) {
                 $params = array_merge($state, $params);
             }
 
-            $session->doLogout($this->authSource);
+            $this->session->doLogout($this->authSource);
 
-            $params['LogoutCompletedHandler'] = array(get_class(), 'logoutCompleted');
+            $params['LogoutCompletedHandler'] = [get_class(), 'logoutCompleted'];
 
             $as = Source::getById($this->authSource);
             if ($as !== null) {
@@ -236,13 +239,13 @@ class Simple
             call_user_func($state['ReturnCallback'], $state);
             assert(false);
         } else {
-            $params = array();
+            $params = [];
             if (isset($state['ReturnStateParam']) || isset($state['ReturnStateStage'])) {
                 assert(isset($state['ReturnStateParam'], $state['ReturnStateStage']));
                 $stateID = State::saveState($state, $state['ReturnStateStage']);
                 $params[$state['ReturnStateParam']] = $stateID;
             }
-            \SimpleSAML\Utils\HTTP::redirectTrustedURL($state['ReturnTo'], $params);
+            HTTP::redirectTrustedURL($state['ReturnTo'], $params);
         }
     }
 
@@ -257,15 +260,13 @@ class Simple
      */
     public function getAttributes()
     {
-
         if (!$this->isAuthenticated()) {
             // Not authenticated
-            return array();
+            return [];
         }
 
         // Authenticated
-        $session = Session::getSessionFromRequest();
-        return $session->getAuthData($this->authSource, 'Attributes');
+        return $this->session->getAuthData($this->authSource, 'Attributes');
     }
 
 
@@ -284,8 +285,7 @@ class Simple
             return null;
         }
 
-        $session = Session::getSessionFromRequest();
-        return $session->getAuthData($this->authSource, $name);
+        return $this->session->getAuthData($this->authSource, $name);
     }
 
 
@@ -296,13 +296,11 @@ class Simple
      */
     public function getAuthDataArray()
     {
-
         if (!$this->isAuthenticated()) {
             return null;
         }
 
-        $session = Session::getSessionFromRequest();
-        return $session->getAuthState($this->authSource);
+        return $this->session->getAuthState($this->authSource);
     }
 
 
@@ -322,10 +320,10 @@ class Simple
             $returnTo = HTTP::getSelfURL();
         }
 
-        $login = Module::getModuleURL('core/as_login.php', array(
+        $login = Module::getModuleURL('core/as_login.php', [
             'AuthId'   => $this->authSource,
             'ReturnTo' => $returnTo,
-        ));
+        ]);
 
         return $login;
     }
@@ -347,10 +345,10 @@ class Simple
             $returnTo = HTTP::getSelfURL();
         }
 
-        $logout = Module::getModuleURL('core/as_logout.php', array(
+        $logout = Module::getModuleURL('core/as_logout.php', [
             'AuthId'   => $this->authSource,
             'ReturnTo' => $returnTo,
-        ));
+        ]);
 
         return $logout;
     }
@@ -373,14 +371,14 @@ class Simple
         }
 
         $scheme = parse_url($url, PHP_URL_SCHEME);
-        $host = parse_url($url, PHP_URL_HOST) ?: HTTP::getSelfHost();
-        $port = parse_url($url, PHP_URL_PORT) ?: (
+        $host = parse_url($url, PHP_URL_HOST) ? : HTTP::getSelfHost();
+        $port = parse_url($url, PHP_URL_PORT) ? : (
             $scheme ? '' : trim(HTTP::getServerPort(), ':')
         );
-        $scheme = $scheme ?: (HTTP::getServerHTTPS() ? 'https' : 'http');
-        $path = parse_url($url, PHP_URL_PATH) ?: '/';
-        $query = parse_url($url, PHP_URL_QUERY) ?: '';
-        $fragment = parse_url($url, PHP_URL_FRAGMENT) ?: '';
+        $scheme = $scheme ? : (HTTP::getServerHTTPS() ? 'https' : 'http');
+        $path = parse_url($url, PHP_URL_PATH) ? : '/';
+        $query = parse_url($url, PHP_URL_QUERY) ? : '';
+        $fragment = parse_url($url, PHP_URL_FRAGMENT) ? : '';
 
         $port = !empty($port) ? ':'.$port : '';
         if (($scheme === 'http' && $port === ':80') || ($scheme === 'https' && $port === ':443')) {
@@ -392,7 +390,7 @@ class Simple
             return $scheme.'://'.$host.$port.$path.($query ? '?'.$query : '').($fragment ? '#'.$fragment : '');
         }
 
-        $base =  trim($this->app_config->getString(
+        $base = trim($this->app_config->getString(
             'baseURL',
             $scheme.'://'.$host.$port
         ), '/');
