@@ -1,5 +1,6 @@
 <?php
 
+namespace SimpleSAML\XHTML;
 
 /**
  * This class implements a generic IdP discovery service, for use in various IdP
@@ -13,13 +14,13 @@
  * @author Andreas Åkre Solberg <andreas@uninett.no>, UNINETT AS.
  * @package SimpleSAMLphp
  */
-class SimpleSAML_XHTML_IdPDisco
-{
 
+class IdPDisco
+{
     /**
      * An instance of the configuration class.
      *
-     * @var SimpleSAML_Configuration
+     * @var \SimpleSAML\Configuration
      */
     protected $config;
 
@@ -34,7 +35,7 @@ class SimpleSAML_XHTML_IdPDisco
     /**
      * An instance of the metadata handler, which will allow us to fetch metadata about IdPs.
      *
-     * @var SimpleSAML_Metadata_MetaDataStorageHandler
+     * @var \SimpleSAML\Metadata\MetaDataStorageHandler
      */
     protected $metadata;
 
@@ -42,7 +43,7 @@ class SimpleSAML_XHTML_IdPDisco
     /**
      * The users session.
      *
-     * @var SimpleSAML_Session
+     * @var \SimpleSAML\Session
      */
     protected $session;
 
@@ -93,7 +94,7 @@ class SimpleSAML_XHTML_IdPDisco
      *
      * @var array
      */
-    protected $scopedIDPList = array();
+    protected $scopedIDPList = [];
 
     /**
      * The URL the user should be redirected to after choosing an IdP.
@@ -118,9 +119,9 @@ class SimpleSAML_XHTML_IdPDisco
         assert(is_string($instance));
 
         // initialize standard classes
-        $this->config = SimpleSAML_Configuration::getInstance();
-        $this->metadata = SimpleSAML_Metadata_MetaDataStorageHandler::getMetadataHandler();
-        $this->session = SimpleSAML_Session::getSessionFromRequest();
+        $this->config = \SimpleSAML\Configuration::getInstance();
+        $this->metadata = \SimpleSAML\Metadata\MetaDataStorageHandler::getMetadataHandler();
+        $this->session = \SimpleSAML\Session::getSessionFromRequest();
         $this->instance = $instance;
         $this->metadataSets = $metadataSets;
 
@@ -128,7 +129,7 @@ class SimpleSAML_XHTML_IdPDisco
 
         // standard discovery service parameters
         if (!array_key_exists('entityID', $_GET)) {
-            throw new Exception('Missing parameter: entityID');
+            throw new \Exception('Missing parameter: entityID');
         } else {
             $this->spEntityId = $_GET['entityID'];
         }
@@ -142,7 +143,7 @@ class SimpleSAML_XHTML_IdPDisco
         $this->log('returnIdParam initially set to ['.$this->returnIdParam.']');
 
         if (!array_key_exists('return', $_GET)) {
-            throw new Exception('Missing parameter: return');
+            throw new \Exception('Missing parameter: return');
         } else {
             $this->returnURL = \SimpleSAML\Utils\HTTP::checkURLAllowed($_GET['return']);
         }
@@ -175,7 +176,7 @@ class SimpleSAML_XHTML_IdPDisco
      */
     protected function log($message)
     {
-        SimpleSAML\Logger::info('idpDisco.'.$this->instance.': '.$message);
+        \SimpleSAML\Logger::info('idpDisco.'.$this->instance.': '.$message);
     }
 
 
@@ -213,13 +214,13 @@ class SimpleSAML_XHTML_IdPDisco
     {
         $prefixedName = 'idpdisco_'.$this->instance.'_'.$name;
 
-        $params = array(
+        $params = [
             // we save the cookies for 90 days
             'lifetime' => (60 * 60 * 24 * 90),
             // the base path for cookies. This should be the installation directory for SimpleSAMLphp
             'path'     => $this->config->getBasePath(),
             'httponly' => false,
-        );
+        ];
 
         \SimpleSAML\Utils\HTTP::setCookie($prefixedName, $value, $params, false);
     }
@@ -249,7 +250,7 @@ class SimpleSAML_XHTML_IdPDisco
             try {
                 $this->metadata->getMetaData($idp, $metadataSet);
                 return $idp;
-            } catch (Exception $e) {
+            } catch (\Exception $e) {
                 // continue
             }
         }
@@ -289,7 +290,7 @@ class SimpleSAML_XHTML_IdPDisco
          * back. Therefore we do some quick and dirty parsing of the query string.
          */
         $qstr = $_SERVER['QUERY_STRING'];
-        $matches = array();
+        $matches = [];
         if (preg_match('/(?:^|&)idp_([^=]+)=/', $qstr, $matches)) {
             return $this->validateIdP(urldecode($matches[1]));
         }
@@ -458,7 +459,7 @@ class SimpleSAML_XHTML_IdPDisco
      */
     protected function getIdPList()
     {
-        $idpList = array();
+        $idpList = [];
         foreach ($this->metadataSets as $metadataSet) {
             $newList = $this->metadata->getList($metadataSet);
             /*
@@ -511,23 +512,23 @@ class SimpleSAML_XHTML_IdPDisco
      */
     protected function start()
     {
-        $idp = $this->getTargetIdp();
+        $idp = $this->getTargetIdP();
         if ($idp !== null) {
             $extDiscoveryStorage = $this->config->getString('idpdisco.extDiscoveryStorage', null);
             if ($extDiscoveryStorage !== null) {
                 $this->log('Choice made ['.$idp.'] (Forwarding to external discovery storage)');
-                \SimpleSAML\Utils\HTTP::redirectTrustedURL($extDiscoveryStorage, array(
+                \SimpleSAML\Utils\HTTP::redirectTrustedURL($extDiscoveryStorage, [
                     'entityID'      => $this->spEntityId,
                     'IdPentityID'   => $idp,
                     'returnIDParam' => $this->returnIdParam,
                     'isPassive'     => 'true',
                     'return'        => $this->returnURL
-                ));
+                ]);
             } else {
                 $this->log(
                     'Choice made ['.$idp.'] (Redirecting the user back. returnIDParam='.$this->returnIdParam.')'
                 );
-                \SimpleSAML\Utils\HTTP::redirectTrustedURL($this->returnURL, array($this->returnIdParam => $idp));
+                \SimpleSAML\Utils\HTTP::redirectTrustedURL($this->returnURL, [$this->returnIdParam => $idp]);
             }
         }
 
@@ -566,7 +567,7 @@ class SimpleSAML_XHTML_IdPDisco
             );
             \SimpleSAML\Utils\HTTP::redirectTrustedURL(
                 $this->returnURL,
-                array($this->returnIdParam => $idpintersection[0])
+                [$this->returnIdParam => $idpintersection[0]]
             );
         }
 
@@ -582,11 +583,48 @@ class SimpleSAML_XHTML_IdPDisco
                 $templateFile = 'selectidp-links.php';
                 break;
             default:
-                throw new Exception('Invalid value for the \'idpdisco.layout\' option.');
+                throw new \Exception('Invalid value for the \'idpdisco.layout\' option.');
         }
 
-        $t = new SimpleSAML_XHTML_Template($this->config, $templateFile, 'disco');
-        $t->data['idplist'] = $idpList;
+        $t = new Template($this->config, $templateFile, 'disco');
+
+        $fallbackLanguage = 'en';
+        $defaultLanguage = $this->config->getString('language.default', $fallbackLanguage);
+        $translator = $t->getTranslator();
+        $language = $translator->getLanguage()->getLanguage();
+        $tryLanguages = [0 => $language, 1 => $defaultLanguage, 2 => $fallbackLanguage];
+
+        $newlist = [];
+        foreach ($idpList as $entityid => $data) {
+            $newlist[$entityid]['entityid'] = $entityid;
+            foreach ($tryLanguages as $lang) {
+                if ($name = $this->getEntityDisplayName($data, $lang)) {
+                    $newlist[$entityid]['name'] = $name;
+                    continue;
+                }
+            }
+            if (empty($newlist[$entityid]['name'])) {
+                $newlist[$entityid]['name'] = $entityid;
+            }
+            foreach ($tryLanguages as $lang) {
+                if (!empty($data['description'][$lang])) {
+                    $newlist[$entityid]['description'] = $data['description'][$lang];
+                    continue;
+                }
+            }
+            if (!empty($data['icon'])) {
+                $newlist[$entityid]['icon'] = $data['icon'];
+                $newlist[$entityid]['iconurl'] = \SimpleSAML\Utils\HTTP::resolveURL($data['icon']);
+            }
+        }
+        usort(
+            $newlist,
+            function ($idpentry1, $idpentry2) {
+                return strcasecmp($idpentry1['name'], $idpentry2['name']);
+            }
+        );
+
+        $t->data['idplist'] = $newlist;
         $t->data['preferredidp'] = $preferredIdP;
         $t->data['return'] = $this->returnURL;
         $t->data['returnIDParam'] = $this->returnIdParam;
@@ -595,4 +633,16 @@ class SimpleSAML_XHTML_IdPDisco
         $t->data['rememberenabled'] = $this->config->getBoolean('idpdisco.enableremember', false);
         $t->show();
     }
+
+    private function getEntityDisplayName(array $idpData, $language)
+    {
+        if (isset($idpData['UIInfo']['DisplayName'][$language])) {
+            return $idpData['UIInfo']['DisplayName'][$language];
+        } elseif (isset($idpData['name'][$language])) {
+            return $idpData['name'][$language];
+        } elseif (isset($idpData['OrganizationDisplayName'][$language])) {
+            return $idpData['OrganizationDisplayName'][$language];
+        }
+        return null;
+    }
 }
