@@ -1,5 +1,6 @@
 <?php
 
+namespace SimpleSAML\Module\consent\Auth\Process;
 
 /**
  * Consent Authentication Processing filter
@@ -9,56 +10,62 @@
  *
  * @package SimpleSAMLphp
  */
-class sspmod_consent_Auth_Process_Consent extends SimpleSAML_Auth_ProcessingFilter
+
+use SimpleSAML\Logger;
+use SimpleSAML\Module;
+use SimpleSAML\Stats;
+use SimpleSAML\Utils;
+
+class Consent extends \SimpleSAML\Auth\ProcessingFilter
 {
     /**
      * Button to receive focus
      *
      * @var string|null
      */
-    private $_focus = null;
+    private $focus = null;
 
     /**
      * Include attribute values
      *
      * @var bool
      */
-    private $_includeValues = false;
+    private $includeValues = false;
 
     /**
      * Check remember consent
      *
      * @var bool
      */
-    private $_checked = false;
+    private $checked = false;
 
     /**
      * Consent backend storage configuration
      *
-     * @var sspmod_consent_Store|null
+     * @var \SimpleSAML\Module\consent\Store|null
      */
-    private $_store = null;
+    private $store = null;
 
     /**
      * Attributes where the value should be hidden
      *
      * @var array
      */
-    private $_hiddenAttributes = array();
+    private $hiddenAttributes = [];
 
     /**
      * Attributes which should not require consent
      *
-     * @var aray
+     * @var array
      */
-    private $_noconsentattributes = array();
+    private $noconsentattributes = [];
 
     /**
      * Whether we should show the "about service"-link on the no consent page.
      *
      * @var bool
      */
-    private $_showNoConsentAboutService = true;
+    private $showNoConsentAboutService = true;
 
 
     /**
@@ -69,7 +76,7 @@ class sspmod_consent_Auth_Process_Consent extends SimpleSAML_Auth_ProcessingFilt
      * @param array $config Configuration information.
      * @param mixed $reserved For future use.
      *
-     * @throws SimpleSAML_Error_Exception if the configuration is not valid.
+     * @throws \SimpleSAML\Error\Exception if the configuration is not valid.
      */
     public function __construct($config, $reserved)
     {
@@ -78,68 +85,68 @@ class sspmod_consent_Auth_Process_Consent extends SimpleSAML_Auth_ProcessingFilt
 
         if (array_key_exists('includeValues', $config)) {
             if (!is_bool($config['includeValues'])) {
-                throw new SimpleSAML_Error_Exception(
+                throw new \SimpleSAML\Error\Exception(
                     'Consent: includeValues must be boolean. '.
                     var_export($config['includeValues'], true).' given.'
                 );
             }
-            $this->_includeValues = $config['includeValues'];
+            $this->includeValues = $config['includeValues'];
         }
 
         if (array_key_exists('checked', $config)) {
             if (!is_bool($config['checked'])) {
-                throw new SimpleSAML_Error_Exception(
+                throw new \SimpleSAML\Error\Exception(
                     'Consent: checked must be boolean. '.
                     var_export($config['checked'], true).' given.'
                 );
             }
-            $this->_checked = $config['checked'];
+            $this->checked = $config['checked'];
         }
 
         if (array_key_exists('focus', $config)) {
-            if (!in_array($config['focus'], array('yes', 'no'), true)) {
-                throw new SimpleSAML_Error_Exception(
+            if (!in_array($config['focus'], ['yes', 'no'], true)) {
+                throw new \SimpleSAML\Error\Exception(
                     'Consent: focus must be a string with values `yes` or `no`. '.
                     var_export($config['focus'], true).' given.'
                 );
             }
-            $this->_focus = $config['focus'];
+            $this->focus = $config['focus'];
         }
 
         if (array_key_exists('hiddenAttributes', $config)) {
             if (!is_array($config['hiddenAttributes'])) {
-                throw new SimpleSAML_Error_Exception(
+                throw new \SimpleSAML\Error\Exception(
                     'Consent: hiddenAttributes must be an array. '.
                     var_export($config['hiddenAttributes'], true).' given.'
                 );
             }
-            $this->_hiddenAttributes = $config['hiddenAttributes'];
+            $this->hiddenAttributes = $config['hiddenAttributes'];
         }
 
         if (array_key_exists('attributes.exclude', $config)) {
             if (!is_array($config['attributes.exclude'])) {
-                throw new SimpleSAML_Error_Exception(
+                throw new \SimpleSAML\Error\Exception(
                     'Consent: attributes.exclude must be an array. '.
                     var_export($config['attributes.exclude'], true).' given.'
                 );
             }
-            $this->_noconsentattributes = $config['attributes.exclude'];
+            $this->noconsentattributes = $config['attributes.exclude'];
         } elseif (array_key_exists('noconsentattributes', $config)) {
-            SimpleSAML\Logger::warning("The 'noconsentattributes' option has been deprecated in favour of 'attributes.exclude'.");
+            Logger::warning("The 'noconsentattributes' option has been deprecated in favour of 'attributes.exclude'.");
             if (!is_array($config['noconsentattributes'])) {
-                throw new SimpleSAML_Error_Exception(
+                throw new \SimpleSAML\Error\Exception(
                     'Consent: noconsentattributes must be an array. '.
                     var_export($config['noconsentattributes'], true).' given.'
                 );
             }
-            $this->_noconsentattributes = $config['noconsentattributes'];
+            $this->noconsentattributes = $config['noconsentattributes'];
         }
 
         if (array_key_exists('store', $config)) {
             try {
-                $this->_store = sspmod_consent_Store::parseStoreConfig($config['store']);
-            } catch (Exception $e) {
-                SimpleSAML\Logger::error(
+                $this->store = \SimpleSAML\Module\consent\Store::parseStoreConfig($config['store']);
+            } catch (\Exception $e) {
+                Logger::error(
                     'Consent: Could not create consent storage: '.
                     $e->getMessage()
                 );
@@ -148,9 +155,9 @@ class sspmod_consent_Auth_Process_Consent extends SimpleSAML_Auth_ProcessingFilt
 
         if (array_key_exists('showNoConsentAboutService', $config)) {
             if (!is_bool($config['showNoConsentAboutService'])) {
-                throw new SimpleSAML_Error_Exception('Consent: showNoConsentAboutService must be a boolean.');
+                throw new \SimpleSAML\Error\Exception('Consent: showNoConsentAboutService must be a boolean.');
             }
-            $this->_showNoConsentAboutService = $config['showNoConsentAboutService'];
+            $this->showNoConsentAboutService = $config['showNoConsentAboutService'];
         }
     }
 
@@ -222,7 +229,7 @@ class sspmod_consent_Auth_Process_Consent extends SimpleSAML_Auth_ProcessingFilt
      *
      * @return void
      *
-     * @throws SimpleSAML_Error_NoPassive if the request was passive and consent is needed.
+     * @throws \SimpleSAML\Error\NoPassive if the request was passive and consent is needed.
      */
     public function process(&$state)
     {
@@ -237,7 +244,7 @@ class sspmod_consent_Auth_Process_Consent extends SimpleSAML_Auth_ProcessingFilt
         $spEntityId = $state['Destination']['entityid'];
         $idpEntityId = $state['Source']['entityid'];
 
-        $metadata = SimpleSAML_Metadata_MetaDataStorageHandler::getMetadataHandler();
+        $metadata = \SimpleSAML\Metadata\MetaDataStorageHandler::getMetadataHandler();
 
         /**
          * If the consent module is active on a bridge $state['saml:sp:IdP']
@@ -251,93 +258,93 @@ class sspmod_consent_Auth_Process_Consent extends SimpleSAML_Auth_ProcessingFilt
             $state['Source'] = $idpmeta;
         }
 
-        $statsData = array('spEntityID' => $spEntityId);
+        $statsData = ['spEntityID' => $spEntityId];
 
         // Do not use consent if disabled
         if (isset($state['Source']['consent.disable']) &&
             self::checkDisable($state['Source']['consent.disable'], $spEntityId)
         ) {
-            SimpleSAML\Logger::debug('Consent: Consent disabled for entity '.$spEntityId.' with IdP '.$idpEntityId);
-            SimpleSAML_Stats::log('consent:disabled', $statsData);
+            Logger::debug('Consent: Consent disabled for entity '.$spEntityId.' with IdP '.$idpEntityId);
+            Stats::log('consent:disabled', $statsData);
             return;
         }
         if (isset($state['Destination']['consent.disable']) &&
             self::checkDisable($state['Destination']['consent.disable'], $idpEntityId)
         ) {
-            SimpleSAML\Logger::debug('Consent: Consent disabled for entity '.$spEntityId.' with IdP '.$idpEntityId);
-            SimpleSAML_Stats::log('consent:disabled', $statsData);
+            Logger::debug('Consent: Consent disabled for entity '.$spEntityId.' with IdP '.$idpEntityId);
+            Stats::log('consent:disabled', $statsData);
             return;
         }
 
-        if ($this->_store !== null) {
+        if ($this->store !== null) {
             $source = $state['Source']['metadata-set'].'|'.$idpEntityId;
             $destination = $state['Destination']['metadata-set'].'|'.$spEntityId;
             $attributes = $state['Attributes'];
 
             // Remove attributes that do not require consent
             foreach ($attributes as $attrkey => $attrval) {
-                if (in_array($attrkey, $this->_noconsentattributes, true)) {
+                if (in_array($attrkey, $this->noconsentattributes, true)) {
                     unset($attributes[$attrkey]);
                 }
             }
 
-            SimpleSAML\Logger::debug('Consent: userid: '.$state['UserID']);
-            SimpleSAML\Logger::debug('Consent: source: '.$source);
-            SimpleSAML\Logger::debug('Consent: destination: '.$destination);
+            Logger::debug('Consent: userid: '.$state['UserID']);
+            Logger::debug('Consent: source: '.$source);
+            Logger::debug('Consent: destination: '.$destination);
 
             $userId = self::getHashedUserID($state['UserID'], $source);
             $targetedId = self::getTargetedID($state['UserID'], $source, $destination);
-            $attributeSet = self::getAttributeHash($attributes, $this->_includeValues);
+            $attributeSet = self::getAttributeHash($attributes, $this->includeValues);
 
-            SimpleSAML\Logger::debug(
+            Logger::debug(
                 'Consent: hasConsent() ['.$userId.'|'.$targetedId.'|'.
                 $attributeSet.']'
             );
 
             try {
-                if ($this->_store->hasConsent($userId, $targetedId, $attributeSet)) {
+                if ($this->store->hasConsent($userId, $targetedId, $attributeSet)) {
                     // Consent already given
-                    SimpleSAML\Logger::stats('consent found');
-                    SimpleSAML_Stats::log('consent:found', $statsData);
+                    Logger::stats('consent found');
+                    Stats::log('consent:found', $statsData);
                     return;
                 }
 
-                SimpleSAML\Logger::stats('consent notfound');
-                SimpleSAML_Stats::log('consent:notfound', $statsData);
+                Logger::stats('consent notfound');
+                Stats::log('consent:notfound', $statsData);
 
-                $state['consent:store'] = $this->_store;
+                $state['consent:store'] = $this->store;
                 $state['consent:store.userId'] = $userId;
                 $state['consent:store.destination'] = $targetedId;
                 $state['consent:store.attributeSet'] = $attributeSet;
-            } catch (Exception $e) {
-                SimpleSAML\Logger::error('Consent: Error reading from storage: '.$e->getMessage());
-                SimpleSAML\Logger::stats('Ccnsent failed');
-                SimpleSAML_Stats::log('consent:failed', $statsData);
+            } catch (\Exception $e) {
+                Logger::error('Consent: Error reading from storage: '.$e->getMessage());
+                Logger::stats('Consent failed');
+                Stats::log('consent:failed', $statsData);
             }
         } else {
-            SimpleSAML\Logger::stats('consent nostorage');
-            SimpleSAML_Stats::log('consent:nostorage', $statsData);
+            Logger::stats('consent nostorage');
+            Stats::log('consent:nostorage', $statsData);
         }
 
-        $state['consent:focus'] = $this->_focus;
-        $state['consent:checked'] = $this->_checked;
-        $state['consent:hiddenAttributes'] = $this->_hiddenAttributes;
-        $state['consent:noconsentattributes'] = $this->_noconsentattributes;
-        $state['consent:showNoConsentAboutService'] = $this->_showNoConsentAboutService;
+        $state['consent:focus'] = $this->focus;
+        $state['consent:checked'] = $this->checked;
+        $state['consent:hiddenAttributes'] = $this->hiddenAttributes;
+        $state['consent:noconsentattributes'] = $this->noconsentattributes;
+        $state['consent:showNoConsentAboutService'] = $this->showNoConsentAboutService;
 
         // user interaction necessary. Throw exception on isPassive request
         if (isset($state['isPassive']) && $state['isPassive'] === true) {
-            SimpleSAML_Stats::log('consent:nopassive', $statsData);
-            throw new SimpleSAML\Module\saml\Error\NoPassive(
-                    \SAML2\Constants::STATUS_REQUESTER,
-                    'Unable to give consent on passive request.'
+            Stats::log('consent:nopassive', $statsData);
+            throw new Module\saml\Error\NoPassive(
+                \SAML2\Constants::STATUS_REQUESTER,
+                'Unable to give consent on passive request.'
             );
         }
 
         // Save state and redirect
-        $id = SimpleSAML_Auth_State::saveState($state, 'consent:request');
-        $url = SimpleSAML\Module::getModuleURL('consent/getconsent.php');
-        \SimpleSAML\Utils\HTTP::redirectTrustedURL($url, array('StateId' => $id));
+        $id = \SimpleSAML\Auth\State::saveState($state, 'consent:request');
+        $url = Module::getModuleURL('consent/getconsent.php');
+        Utils\HTTP::redirectTrustedURL($url, ['StateId' => $id]);
     }
 
 
@@ -351,7 +358,7 @@ class sspmod_consent_Auth_Process_Consent extends SimpleSAML_Auth_ProcessingFilt
      */
     public static function getHashedUserID($userid, $source)
     {
-        return hash('sha1', $userid.'|'.SimpleSAML\Utils\Config::getSecretSalt().'|'.$source);
+        return hash('sha1', $userid.'|'.Utils\Config::getSecretSalt().'|'.$source);
     }
 
 
@@ -366,7 +373,7 @@ class sspmod_consent_Auth_Process_Consent extends SimpleSAML_Auth_ProcessingFilt
      */
     public static function getTargetedID($userid, $source, $destination)
     {
-        return hash('sha1', $userid.'|'.SimpleSAML\Utils\Config::getSecretSalt().'|'.$source.'|'.$destination);
+        return hash('sha1', $userid.'|'.Utils\Config::getSecretSalt().'|'.$source.'|'.$destination);
     }
 
 
