@@ -1,70 +1,53 @@
 <?php
 
-
-
-// Load SimpleSAMLphp, configuration
-$config = SimpleSAML_Configuration::getInstance();
-$session = SimpleSAML_Session::getSessionFromRequest();
+// Load SimpleSAMLphp configuration
+$config = \SimpleSAML\Configuration::getInstance();
+$session = \SimpleSAML\Session::getSessionFromRequest();
 
 // Check if valid local session exists.
 if ($config->getBoolean('admin.protectindexpage', false)) {
-    SimpleSAML\Utils\Auth::requireAdmin();
+    \SimpleSAML\Utils\Auth::requireAdmin();
 }
-$loginurl = SimpleSAML\Utils\Auth::getAdminLoginURL();
-$isadmin = SimpleSAML\Utils\Auth::isAdmin();
+$logouturl = \SimpleSAML\Utils\Auth::getAdminLogoutURL();
+$loginurl = \SimpleSAML\Utils\Auth::getAdminLoginURL();
+$isadmin = \SimpleSAML\Utils\Auth::isAdmin();
 
-
-
-
-	
-	
-	
-$links = array();
-$links_welcome = array();
-$links_config = array();
-$links_auth = array();
-$links_federation = array();
+$links = [];
+$links_welcome = [];
+$links_config = [];
+$links_auth = [];
+$links_federation = [];
 
 if ($config->getBoolean('idpdisco.enableremember', false)) {
-    $links_federation[] = array(
+    $links_federation[] = [
         'href' => 'cleardiscochoices.php',
         'text' => '{core:frontpage:link_cleardiscochoices}',
-    );
+    ];
 }
 
 
-$links_federation[] = array(
-    'href' => \SimpleSAML\Utils\HTTP::getBaseURL() . 'admin/metadata-converter.php',
+$links_federation[] = [
+    'href' => \SimpleSAML\Utils\HTTP::getBaseURL().'admin/metadata-converter.php',
     'text' => '{core:frontpage:link_xmlconvert}',
-);
+];
 
-
-
-
-$allLinks = array(
+$allLinks = [
     'links' => &$links,
     'welcome' => &$links_welcome,
     'config' => &$links_config,
     'auth' => &$links_auth,
     'federation' => &$links_federation,
-);
-SimpleSAML\Module::callHooks('frontpage', $allLinks);
+];
+\SimpleSAML\Module::callHooks('frontpage', $allLinks);
 
 
-$metadataHosted = array();
-SimpleSAML\Module::callHooks('metadata_hosted', $metadataHosted);
+$metadataHosted = [];
+\SimpleSAML\Module::callHooks('metadata_hosted', $metadataHosted);
 
 
+$metadata = \SimpleSAML\Metadata\MetaDataStorageHandler::getMetadataHandler();
 
-
-
-
-
-
-
-$metadata = SimpleSAML_Metadata_MetaDataStorageHandler::getMetadataHandler();
-
-$metaentries = array('hosted' => $metadataHosted, 'remote' => array() );
+$metaentries = ['hosted' => $metadataHosted, 'remote' => []];
 
 
 if ($isadmin) {
@@ -77,9 +60,10 @@ if ($config->getBoolean('enable.saml20-idp', false) === true) {
         $metaentries['hosted']['saml20-idp'] = $metadata->getMetaDataCurrent('saml20-idp-hosted');
         $metaentries['hosted']['saml20-idp']['metadata-url'] =
             $config->getBasePath().'saml2/idp/metadata.php?output=xhtml';
-        if ($isadmin)
+        if ($isadmin) {
             $metaentries['remote']['saml20-sp-remote'] = $metadata->getList('saml20-sp-remote');
-    } catch(Exception $e) {
+        }
+    } catch (Exception $e) {
         \SimpleSAML\Logger::error('Federation: Error loading saml20-idp: '.$e->getMessage());
     }
 }
@@ -88,10 +72,11 @@ if ($config->getBoolean('enable.shib13-idp', false) === true) {
         $metaentries['hosted']['shib13-idp'] = $metadata->getMetaDataCurrent('shib13-idp-hosted');
         $metaentries['hosted']['shib13-idp']['metadata-url'] =
             $config->getBasePath().'shib13/idp/metadata.php?output=xhtml';
-        if ($isadmin)
+        if ($isadmin) {
             $metaentries['remote']['shib13-sp-remote'] = $metadata->getList('shib13-sp-remote');
-    } catch(Exception $e) {
-        \SimpleSAML\Logger::error('Federation: Error loading shib13-idp: ' . $e->getMessage());
+        }
+    } catch (Exception $e) {
+        \SimpleSAML\Logger::error('Federation: Error loading shib13-idp: '.$e->getMessage());
     }
 }
 if ($config->getBoolean('enable.adfs-idp', false) === true) {
@@ -99,12 +84,13 @@ if ($config->getBoolean('enable.adfs-idp', false) === true) {
         $metaentries['hosted']['adfs-idp'] = $metadata->getMetaDataCurrent('adfs-idp-hosted');
         $metaentries['hosted']['adfs-idp']['metadata-url'] = \SimpleSAML\Module::getModuleURL(
             'adfs/idp/metadata.php',
-            array('output' => 'xhtml')
+            ['output' => 'xhtml']
         );
-        if ($isadmin)
+        if ($isadmin) {
             $metaentries['remote']['adfs-sp-remote'] = $metadata->getList('adfs-sp-remote');
-    } catch(Exception $e) {
-        SimpleSAML\Logger::error('Federation: Error loading adfs-idp: ' . $e->getMessage());
+        }
+    } catch (Exception $e) {
+        \SimpleSAML\Logger::error('Federation: Error loading adfs-idp: '.$e->getMessage());
     }
 }
 
@@ -114,18 +100,18 @@ foreach ($metaentries['remote'] as $key => $value) {
     }
 }
 
-$t = new SimpleSAML_XHTML_Template($config, 'core:frontpage_federation.tpl.php');
+$t = new \SimpleSAML\XHTML\Template($config, 'core:frontpage_federation.tpl.php');
 $translator = $t->getTranslator();
 
 $language = $translator->getLanguage()->getLanguage();
 $fallbackLanguage = 'en';
 $defaultLanguage = $config->getString('language.default', $fallbackLanguage);
 
-$translators = array(
+$translators = [
     'name' => 'name_translated',
     'descr' => 'descr_translated',
     'OrganizationDisplayName' => 'organizationdisplayname_translated',
-);
+];
 
 foreach ($metaentries['hosted'] as $index => $entity) {
     foreach ($translators as $old => $new) {
@@ -135,7 +121,7 @@ foreach ($metaentries['hosted'] as $index => $entity) {
             $metaentries['hosted'][$index][$new] = $entity[$old][$defaultLanguage];
         } elseif (isset($entity[$old][$fallbackLanguage])) {
             $metaentries['hosted'][$index][$new] = $entity[$old][$fallbackLanguage];
-	}
+        }
     }
 }
 foreach ($metaentries['remote'] as $key => $set) {
@@ -155,7 +141,7 @@ foreach ($metaentries['remote'] as $key => $set) {
 }
 
 # look up translated string
-$mtype = array(
+$mtype = [
     'saml20-sp-remote' => $translator->noop('{admin:metadata_saml20-sp}'),
     'saml20-sp-hosted' => $translator->noop('{admin:metadata_saml20-sp}'),
     'saml20-idp-remote' => $translator->noop('{admin:metadata_saml20-idp}'),
@@ -168,23 +154,22 @@ $mtype = array(
     'adfs-sp-hosted' => $translator->noop('{admin:metadata_adfs-sp}'),
     'adfs-idp-remote' => $translator->noop('{admin:metadata_adfs-idp}'),
     'adfs-idp-hosted' => $translator->noop('{admin:metadata_adfs-idp}'),
-);
+];
 
 $t->data['pageid'] = 'frontpage_federation';
 $t->data['isadmin'] = $isadmin;
 $t->data['loginurl'] = $loginurl;
-
+$t->data['logouturl'] = $logouturl;
 
 $t->data['links'] = $links;
 $t->data['links_welcome'] = $links_welcome;
 $t->data['links_config'] = $links_config;
 $t->data['links_auth'] = $links_auth;
 $t->data['links_federation'] = $links_federation;
+$t->data['header'] = $translator->t('{core:frontpage:page_title}');
 
-
+$t->data['metadata_url'] = \SimpleSAML\Module::getModuleURL('core/show_metadata.php');
 $t->data['metaentries'] = $metaentries;
 $t->data['mtype'] = $mtype;
 
-
 $t->show();
-
