@@ -1,8 +1,10 @@
 <?php
+
 namespace SimpleSAML\Test\Utils;
 
 use PHPUnit\Framework\TestCase;
 use SimpleSAML\Utils\HTTP;
+use SimpleSAML\Configuration;
 
 class HTTPTest extends TestCase
 {
@@ -37,7 +39,7 @@ class HTTPTest extends TestCase
      */
     public function testAddURLParametersInvalidURL()
     {
-        HTTP::addURLParameters(array(), array());
+        HTTP::addURLParameters([], []);
     }
 
     /**
@@ -56,23 +58,23 @@ class HTTPTest extends TestCase
     public function testAddURLParameters()
     {
         $url = 'http://example.com/';
-        $params = array(
+        $params = [
             'foo' => 'bar',
             'bar' => 'foo',
-        );
+        ];
         $this->assertEquals($url.'?foo=bar&bar=foo', HTTP::addURLParameters($url, $params));
 
         $url = 'http://example.com/?';
-        $params = array(
+        $params = [
             'foo' => 'bar',
             'bar' => 'foo',
-        );
+        ];
         $this->assertEquals($url.'foo=bar&bar=foo', HTTP::addURLParameters($url, $params));
 
         $url = 'http://example.com/?foo=bar';
-        $params = array(
+        $params = [
             'bar' => 'foo',
-        );
+        ];
         $this->assertEquals($url.'&bar=foo', HTTP::addURLParameters($url, $params));
     }
 
@@ -125,9 +127,9 @@ class HTTPTest extends TestCase
     {
         $original = $_SERVER;
 
-        \SimpleSAML_Configuration::loadFromArray(array(
+        Configuration::loadFromArray([
             'baseurlpath' => '',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
         $_SERVER['SERVER_PORT'] = '80';
         $this->assertEquals('localhost', HTTP::getSelfHost());
         $_SERVER['SERVER_PORT'] = '3030';
@@ -143,9 +145,9 @@ class HTTPTest extends TestCase
     {
         $original = $_SERVER;
 
-        \SimpleSAML_Configuration::loadFromArray(array(
+        Configuration::loadFromArray([
             'baseurlpath' => '',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
 
         // standard port for HTTP
         $_SERVER['SERVER_PORT'] = '80';
@@ -174,9 +176,9 @@ class HTTPTest extends TestCase
          * Test a URL pointing to a script that's not part of the public interface. This allows us to test calls to
          * getSelfURL() from scripts outside of SimpleSAMLphp
          */
-        \SimpleSAML_Configuration::loadFromArray(array(
+        Configuration::loadFromArray([
             'baseurlpath' => 'http://example.com/simplesaml/',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
         $url = 'https://example.com/app/script.php/some/path?foo=bar';
         $this->setupEnvFromURL($url);
         $_SERVER['SCRIPT_FILENAME'] = '/var/www/app/script.php';
@@ -187,9 +189,9 @@ class HTTPTest extends TestCase
         $this->assertEquals('https://'.HTTP::getSelfHostWithNonStandardPort(), HTTP::getSelfURLHost());
 
         // test a request URI that doesn't match the current script
-        $cfg = \SimpleSAML_Configuration::loadFromArray(array(
+        $cfg = Configuration::loadFromArray([
             'baseurlpath' => 'https://example.org/simplesaml/',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
         $baseDir = $cfg->getBaseDir();
         $_SERVER['SCRIPT_FILENAME'] = $baseDir.'www/module.php';
         $this->setupEnvFromURL('http://www.example.com/protected/resource.asp?foo=bar');
@@ -201,9 +203,9 @@ class HTTPTest extends TestCase
         $this->assertEquals('http://www.example.com', HTTP::getSelfURLHost());
 
         // test a valid, full URL, based on a full URL in the configuration
-        \SimpleSAML_Configuration::loadFromArray(array(
+        Configuration::loadFromArray([
             'baseurlpath' => 'https://example.com/simplesaml/',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
         $this->setupEnvFromURL('http://www.example.org/module.php/module/file.php?foo=bar');
         $this->assertEquals(
             'https://example.com/simplesaml/module.php/module/file.php?foo=bar',
@@ -215,9 +217,9 @@ class HTTPTest extends TestCase
         $this->assertEquals('https://'.HTTP::getSelfHostWithNonStandardPort(), HTTP::getSelfURLHost());
 
         // test a valid, full URL, based on a full URL *without* a trailing slash in the configuration
-        \SimpleSAML_Configuration::loadFromArray(array(
+        Configuration::loadFromArray([
             'baseurlpath' => 'https://example.com/simplesaml',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
         $this->assertEquals(
             'https://example.com/simplesaml/module.php/module/file.php?foo=bar',
             HTTP::getSelfURL()
@@ -228,9 +230,9 @@ class HTTPTest extends TestCase
         $this->assertEquals('https://'.HTTP::getSelfHostWithNonStandardPort(), HTTP::getSelfURLHost());
 
         // test a valid, full URL, based on a full URL *without* a path in the configuration
-        \SimpleSAML_Configuration::loadFromArray(array(
+        Configuration::loadFromArray([
             'baseurlpath' => 'https://example.com',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
         $this->assertEquals(
             'https://example.com/module.php/module/file.php?foo=bar',
             HTTP::getSelfURL()
@@ -241,9 +243,9 @@ class HTTPTest extends TestCase
         $this->assertEquals('https://'.HTTP::getSelfHostWithNonStandardPort(), HTTP::getSelfURLHost());
 
         // test a valid, full URL, based on a relative path in the configuration
-        \SimpleSAML_Configuration::loadFromArray(array(
+        Configuration::loadFromArray([
             'baseurlpath' => '/simplesaml/',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
         $this->setupEnvFromURL('http://www.example.org/simplesaml/module.php/module/file.php?foo=bar');
         $this->assertEquals(
             'http://www.example.org/simplesaml/module.php/module/file.php?foo=bar',
@@ -255,9 +257,9 @@ class HTTPTest extends TestCase
         $this->assertEquals('http://'.HTTP::getSelfHostWithNonStandardPort(), HTTP::getSelfURLHost());
 
         // test a valid, full URL, based on a relative path in the configuration and a non standard port
-        \SimpleSAML_Configuration::loadFromArray(array(
+        Configuration::loadFromArray([
             'baseurlpath' => '/simplesaml/',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
         $this->setupEnvFromURL('http://example.org:8080/simplesaml/module.php/module/file.php?foo=bar');
         $this->assertEquals(
             'http://example.org:8080/simplesaml/module.php/module/file.php?foo=bar',
@@ -269,9 +271,9 @@ class HTTPTest extends TestCase
         $this->assertEquals('http://'.HTTP::getSelfHostWithNonStandardPort(), HTTP::getSelfURLHost());
 
         // test a valid, full URL, based on a relative path in the configuration, a non standard port and HTTPS
-        \SimpleSAML_Configuration::loadFromArray(array(
+        Configuration::loadFromArray([
             'baseurlpath' => '/simplesaml/',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
         $this->setupEnvFromURL('https://example.org:8080/simplesaml/module.php/module/file.php?foo=bar');
         $this->assertEquals(
             'https://example.org:8080/simplesaml/module.php/module/file.php?foo=bar',
@@ -295,24 +297,24 @@ class HTTPTest extends TestCase
     {
         $original = $_SERVER;
 
-        \SimpleSAML_Configuration::loadFromArray(array(
-            'trusted.url.domains' => array('sp.example.com', 'app.example.com'),
+        Configuration::loadFromArray([
+            'trusted.url.domains' => ['sp.example.com', 'app.example.com'],
             'trusted.url.regex' => false,
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
 
         $_SERVER['REQUEST_URI'] = '/module.php';
 
-        $allowed = array(
+        $allowed = [
             'https://sp.example.com/',
             'http://sp.example.com/',
             'https://app.example.com/',
             'http://app.example.com/',
-        );
+        ];
         foreach ($allowed as $url) {
             $this->assertEquals(HTTP::checkURLAllowed($url), $url);
         }
 
-        $this->setExpectedException('SimpleSAML_Error_Exception');
+        $this->setExpectedException('\SimpleSAML\Error\Exception');
         HTTP::checkURLAllowed('https://evil.com');
 
         $_SERVER = $original;
@@ -325,26 +327,26 @@ class HTTPTest extends TestCase
     {
         $original = $_SERVER;
 
-        \SimpleSAML_Configuration::loadFromArray(array(
-            'trusted.url.domains' => array('.*\.example\.com'),
+        Configuration::loadFromArray([
+            'trusted.url.domains' => ['.*\.example\.com'],
             'trusted.url.regex' => true,
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
 
         $_SERVER['REQUEST_URI'] = '/module.php';
 
-        $allowed = array(
+        $allowed = [
             'https://sp.example.com/',
             'http://sp.example.com/',
             'https://app1.example.com/',
             'http://app1.example.com/',
             'https://app2.example.com/',
             'http://app2.example.com/',
-        );
+        ];
         foreach ($allowed as $url) {
             $this->assertEquals(HTTP::checkURLAllowed($url), $url);
         }
 
-        $this->setExpectedException('SimpleSAML_Error_Exception');
+        $this->setExpectedException('\SimpleSAML\Error\Exception');
         HTTP::checkURLAllowed('https://evil.com');
 
         $_SERVER = $original;
@@ -402,16 +404,28 @@ class HTTPTest extends TestCase
     {
         $original = $_SERVER;
 
-        \SimpleSAML_Configuration::loadFromArray(array(
-            'trusted.url.domains' => array('app\.example\.com'),
+        Configuration::loadFromArray([
+            'trusted.url.domains' => ['app\.example\.com'],
             'trusted.url.regex' => true,
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
 
         $_SERVER['REQUEST_URI'] = '/module.php';
 
-        $this->setExpectedException('SimpleSAML_Error_Exception');
+        $this->setExpectedException('\SimpleSAML\Error\Exception');
         HTTP::checkURLAllowed('https://app.example.com.evil.com');
 
         $_SERVER = $original;
     }
+
+    /**
+     * @covers SimpleSAML\Utils\HTTP::getFirstPathElement()
+     */
+    public function testGetFirstPathElement()
+    {
+        $original = $_SERVER;
+        $_SERVER['SCRIPT_NAME'] = '/test/tmp.php';
+        $this->assertEquals(HTTP::getFirstPathElement(), '/test');
+        $this->assertEquals(HTTP::getFirstPathElement(false), 'test');
+        $_SERVER = $original;
+    }
 }
